# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.4.0

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.3.1...fcb5899fd3671ef14aa98dbafd7c64d44b6d19ee))

### Maintenance and upkeep improvements

- Bump frontend version limit [#35](https://github.com/trungleduc/ipecharts/pull/35) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2025-09-11&to=2025-09-11&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2025-09-11..2025-09-11&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 1.3.1

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.3.0...5b8c2b3f7c2bb5874c296479322d31b4035a1de0))

### Enhancements made

- Support ipywidgets 7 [#34](https://github.com/trungleduc/ipecharts/pull/34) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2025-03-15&to=2025-09-11&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2025-03-15..2025-09-11&type=Issues)

## 1.3.0

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.2.1...99c2b64215de91658b75927c4523f0766f217842))

### Enhancements made

- Allow sending raw js function [#31](https://github.com/trungleduc/ipecharts/pull/31) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2025-03-05&to=2025-03-15&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2025-03-05..2025-03-15&type=Issues)

## 1.2.1

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.2.0...2cb47f072ac80cb67e4469755e47a434add0b7b0))

### Bugs fixed

- Fix event init [#29](https://github.com/trungleduc/ipecharts/pull/29) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2025-02-08&to=2025-03-05&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2025-02-08..2025-03-05&type=Issues)

## 1.2.0

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.1.0...fa4727d1fb807d44b2ff08b411587fea229f3a15))

### Enhancements made

- feat: make ipecharts compatible with notebook\<7 [#26](https://github.com/trungleduc/ipecharts/pull/26) ([@iisakkirotko](https://github.com/iisakkirotko))

### Maintenance and upkeep improvements

- Bump upload artifact action [#27](https://github.com/trungleduc/ipecharts/pull/27) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-12-31&to=2025-02-08&type=c))

[@iisakkirotko](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Aiisakkirotko+updated%3A2024-12-31..2025-02-08&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-12-31..2025-02-08&type=Issues)

## 1.1.0

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.0.8...c250f7f92e8d8359d6b729da4159f8104ac97f4a))

### Enhancements made

- Support chart actions [#23](https://github.com/trungleduc/ipecharts/pull/23) ([@trungleduc](https://github.com/trungleduc))
- Add event [#21](https://github.com/trungleduc/ipecharts/pull/21) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-10-02&to=2024-12-31&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-10-02..2024-12-31&type=Issues)

## 1.0.8

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.0.7...04dd1d26c7c736bd1cee470cb135072882b43e24))

### Enhancements made

- refactor classes [#16](https://github.com/trungleduc/ipecharts/pull/16) ([@dfguerrerom](https://github.com/dfguerrerom))
- Refactor widget classes [#14](https://github.com/trungleduc/ipecharts/pull/14) ([@trungleduc](https://github.com/trungleduc))

### Bugs fixed

- Defer chart init [#18](https://github.com/trungleduc/ipecharts/pull/18) ([@trungleduc](https://github.com/trungleduc))

### Maintenance and upkeep improvements

- Add integration tests [#15](https://github.com/trungleduc/ipecharts/pull/15) ([@trungleduc](https://github.com/trungleduc))

### Documentation improvements

- add dynamic style vide [#12](https://github.com/trungleduc/ipecharts/pull/12) ([@dfguerrerom](https://github.com/dfguerrerom))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-09-24&to=2024-10-02&type=c))

[@dfguerrerom](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Adfguerrerom+updated%3A2024-09-24..2024-10-02&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-09-24..2024-10-02&type=Issues)

## 1.0.7

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.0.6...21d5cf521d53adaf99fe42d5bd95ca253cb9a3d4))

### Enhancements made

- feat: add style config [#10](https://github.com/trungleduc/ipecharts/pull/10) ([@dfguerrerom](https://github.com/dfguerrerom))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-08-29&to=2024-09-24&type=c))

[@dfguerrerom](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Adfguerrerom+updated%3A2024-08-29..2024-09-24&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-08-29..2024-09-24&type=Issues)

## 1.0.6

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.0.5...ccb7f5aa0641e623ced8609a23ae912212cba1bb))

### Bugs fixed

- Bundle `@lumino/polling` [#6](https://github.com/trungleduc/ipecharts/pull/6) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-06-18&to=2024-08-29&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-06-18..2024-08-29&type=Issues)

## 1.0.5

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.0.4...cad6d7fa10b8962fc095450b179972036310f51d))

### Bugs fixed

- Fix code generation on Windows [#4](https://github.com/trungleduc/ipecharts/pull/4) ([@trungleduc](https://github.com/trungleduc))

### Documentation improvements

- Fix code generation on Windows [#4](https://github.com/trungleduc/ipecharts/pull/4) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-06-17&to=2024-06-18&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-06-17..2024-06-18&type=Issues)

## 1.0.4

No merged PRs

## 1.0.3

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.0.2...3fff7d5ed4662f58012597af37ab94737a2033f3))

### Enhancements made

- Fix update logic again [#3](https://github.com/trungleduc/ipecharts/pull/3) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-06-16&to=2024-06-17&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-06-16..2024-06-17&type=Issues)

## 1.0.2

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.0.1...c0f24dfeeffc388ba8f2b27048c38c5466bf2026))

### Bugs fixed

- Fix update propagation logic [#2](https://github.com/trungleduc/ipecharts/pull/2) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-06-15&to=2024-06-16&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-06-15..2024-06-16&type=Issues)

## 1.0.1

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.0.0...fd747d36fdf184c884f46f1381806e6e6be549c4))

### Enhancements made

- Bump frontend version [#1](https://github.com/trungleduc/ipecharts/pull/1) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-06-15&to=2024-06-15&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-06-15..2024-06-15&type=Issues)

## 1.0.0

No merged PRs
